@@ -1,6 +1,6 @@
 from scale_lidar_io import *
+from .JSONBinaryEncoder import JSONBinaryEncoder as JSONBinaryEncoder
 from .scene import DebugLidarScene as LidarScene
-from .lidarLiteHelper import get_points, get_cameras, combine_scenes
 
 
 def import_test():
