@@ -8,7 +8,7 @@ from bson.objectid import ObjectId
 from pyquaternion import Quaternion
 import base64
 import requests
-from .lidarLiteHelper import get_points, get_cameras, combine_scenes
+from .lidarLiteHelper import get_points, get_cameras, combine_scenes, load_bs4
 
 class DebugLidarScene(LidarScene):
     '''
@@ -144,3 +144,8 @@ class DebugLidarScene(LidarScene):
         get_cameras(self, path, camera)
 
         combine_scenes(camera, path, filename)
+
+    def from_bs4(self, file):
+        load_bs4(self, file)
+
+
